# If you don't want to build with maven, and use straight ant instead,
# give rpmbuild option '--without maven'

%define with_maven 0
%define without_maven %{?with_maven:0}%{!?with_maven:1}

%define base_name       collections
%define short_name      commons-%{base_name}
%define section         free

Name:       apache-%{short_name}
Version:    3.2.2
Release:    1
Epoch:      0
Summary:    Provides new interfaces, implementations and utilities for Java Collections
License:    Apache Software License 
Group:      Development/Java
URL:        http://commons.apache.org/%{base_name}/
Source0:    http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:    pom-maven2jpp-depcat.xsl
Source2:    pom-maven2jpp-newdepmap.xsl
Source3:    pom-maven2jpp-mapdeps.xsl
Source4:    commons-collections-3.2-jpp-depmap.xml

Patch0:         %{name}-3.2.2-javadoc-nonet.patch
Patch1:         %{name}-use-nanoTime-in-Buffers.patch
Patch2:         apache-commons-collections-3.2.1-java8-compat.patch
Patch3:         apache-commons-collections-3.2.2-build_xml.patch
Patch4:		commons-collections-3.2.2-Manifest.patch

BuildRequires:  dos2unix
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  java-rpmbuild >= 0:1.7.2
BuildRequires:  xml-commons-apis >= 1.3
%if %{with_maven}
BuildRequires:  maven >= 0:1.1
BuildRequires:  maven-plugins-base
BuildRequires:  maven-plugin-test
BuildRequires:  maven-plugin-xdoc
BuildRequires:  maven-plugin-license
BuildRequires:  maven-plugin-changes
BuildRequires:  maven-plugin-jdepend
BuildRequires:  maven-plugin-jdiff
BuildRequires:  maven-plugin-jxr
BuildRequires:  maven-plugin-tasklist
BuildRequires:  maven-plugin-developer-activity
BuildRequires:  maven-plugin-file-activity
BuildRequires:  saxon
BuildRequires:  saxon-scripts
%endif

BuildArch:      noarch

%rename jakarta-%{short_name}
Provides: commons-collections

%description
The introduction of the Collections API by Sun in JDK 1.2 has been a
boon to quick and effective Java programming. Ready access to powerful
data structures has accelerated development by reducing the need for
custom container classes around each core object. Most Java2 APIs are
significantly easier to use because of the Collections API.
However, there are certain holes left unfilled by Sun's
implementations, and the Jakarta-Commons Collections Component strives
to fulfill them. Among the features of this package are:
- special-purpose implementations of Lists and Maps for fast access
- adapter classes from Java1-style containers (arrays, enumerations) to
Java2-style collections.
- methods to test or create typical set-theory properties of collections
such as union, intersection, and closure.

%package testframework
Summary:        Testframework for %{name}
Group:          Development/Java
Requires:       %{name} = %{EVRD}
%rename jakarta-%{short_name}-testframework

%description testframework
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Java
%rename jakarta-%{short_name}-javadoc

%description javadoc
%{summary}.

%package testframework-javadoc
Summary:        Javadoc for %{name}-testframework
Group:          Development/Java
%rename jakarta-%{short_name}-testframework-javadoc

%description testframework-javadoc
%{summary}.

%if %{with_maven}
%package manual
Summary:        Documents for %{name}
Group:          Development/Java
%rename jakarta-%{short_name}-manual

%description manual
%{summary}.
%endif

%prep
cat <<EOT

                If you dont want to build with maven,
                give rpmbuild option '--without maven'

EOT

%setup -q -n %{short_name}-%{version}-src
%remove_java_binaries

find . -name "*.java" |xargs dos2unix

%patch0 -p1 -b .sav0
%patch1 -p1 -b .sav1
%patch2 -p1 -b .java8
%patch3 -p1 -b .nofail
%patch4 -p1 -b .manifest

# Fix file eof
%{__sed} -i 's/\r//' LICENSE.txt
%{__sed} -i 's/\r//' PROPOSAL.html
%{__sed} -i 's/\r//' README.txt
%{__sed} -i 's/\r//' NOTICE.txt

%build
%if %{with_maven}
export DEPCAT=$(pwd)/commons-collections-3.1-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > %{short_name}-%{version}-depmap.new.xml
fi

for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

export MAVEN_HOME_LOCAL=$(pwd)/.maven

#        -Dmaven.test.failure.ignore=true \
maven \
        -Dmaven.repo.remote=file:/usr/share/maven/repository \
        -Dmaven.home.local=${MAVEN_HOME_LOCAL} \
        jar:jar javadoc:generate xdoc:transform
%ant tf.javadoc
%else
%ant -Djava.io.tmpdir=. test dist tf.javadoc
%endif

%install
# jars
install -d -m 755 %{buildroot}%{_javadir}
%if %{with_maven}
install -m 644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
install -m 644 target/%{short_name}-testframework-%{version}.jar %{buildroot}%{_javadir}/%{name}-testframework-%{version}.jar
%else
install -m 644 build/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
install -m 644 build/%{short_name}-testframework-%{version}.jar %{buildroot}%{_javadir}/%{name}-testframework-%{version}.jar
%endif

%add_to_maven_depmap %{short_name} %{short_name} %{version} JPP %{short_name}
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|apache-||g"`; done)
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

# pom
install -d -m 755 %{buildroot}%{_datadir}/maven2/poms
install -m 644 pom.xml \
    %{buildroot}%{_datadir}/maven2/poms/JPP-%{short_name}.pom

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
%if %{with_maven}
cp -pr target/docs/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%else
cp -pr build/docs/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%endif
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}
rm -rf target/docs/apidocs

# testframework-javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}-testframework-%{version}
cp -pr build/docs/testframework/* %{buildroot}%{_javadocdir}/%{name}-testframework-%{version}
ln -s %{name}-testframework-%{version} %{buildroot}%{_javadocdir}/%{name}-testframework 

# manual
%if %{with_maven}
install -d -m 755 %{buildroot}%{_docdir}/%{name}-%{version}
cp -pr target/docs/* %{buildroot}%{_docdir}/%{name}-%{version}
%endif

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc PROPOSAL.html README.txt LICENSE.txt NOTICE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_javadir}/%{short_name}.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}

%files testframework
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-testframework-%{version}.jar
%{_javadir}/%{name}-testframework.jar
%{_javadir}/%{short_name}-testframework-%{version}.jar
%{_javadir}/%{short_name}-testframework.jar

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files testframework-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-testframework-%{version}
%{_javadocdir}/%{name}-testframework

%if %{with_maven}
%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}
%endif




%changelog

* Fri Jan 15 2016 Denis Silakov <dsilakov@gmail.com> 0:3.2.2-1
- (0d16e02) Updated to 3.2.2


